# Alman Ruby bindings
# API Docs are located at http://docs.almanapi.com
require 'cgi'
require 'set'
require 'openssl'
require 'rest_client'
require 'json'
require 'base64'

# Version
require 'alman/version'

# Errors
require 'alman/errors/alman_error'
require 'alman/errors/api_error'
require 'alman/errors/api_connection_error'
require 'alman/errors/authentication_error'

# Wrapper around RestClient
require 'alman/apibits/requester'

# Builders for creating API methods.
require 'alman/apibits/path_builder'
require 'alman/apibits/headers_builder'
require 'alman/apibits/params_builder'
require 'alman/apibits/api_method'

# Generic resources
require 'alman/apibits/api_endpoint'
require 'alman/apibits/api_client'
require 'alman/apibits/api_object'
require 'alman/apibits/api_resource'
require 'alman/apibits/api_list'
require 'alman/apibits/util'

# API specific resources
require 'alman/resources/calendar'
require 'alman/resources/vacancy'
require 'alman/resources/booking'

# API specific endpoints
require 'alman/endpoints/calendars_endpoint'
require 'alman/endpoints/calendar_vacancies_endpoint'
require 'alman/endpoints/vacancies_endpoint'
require 'alman/endpoints/vacancy_bookings_endpoint'
require 'alman/endpoints/bookings_endpoint'

# API specific clients
require 'alman/clients/default_client'


module Alman
  @api_base = "http://almanapi.com/api/v0"
  @api_staging = ""
  @api_version = "v0"
  @support_email = "support@almanapi.com"
  @docs_url = "http://docs.almanapi.com"

  class << self
    attr_accessor :api_base, :api_version
    attr_reader :api_staging, :support_email, :docs_url
    attr_accessor :api_key
  end

  def self.default_client
    DefaultClient.new(Alman.api_key)
  end
end
